@@ -1,15 +1,12 @@
 import time
-import datetime as dt
 import requests
 import json
 from concurrent.futures import ThreadPoolExecutor, as_completed
 import copy
 import logging
-import warnings
 
 from pmaw.RateLimit import RateLimit
 from pmaw.Request import Request
-from pmaw.utils.slices import timeslice, mapslice
 
 log = logging.getLogger(__name__)
 
@@ -181,7 +178,7 @@ class PushshiftAPIBase(object):
         # shutdown executor
         try:
             exc.shutdown(wait=wait, cancel_futures=cancel_futures)
-        except:
+        except Exception:
             # TODO: manually cancel pending futures
             exc.shutdown(wait=wait)
 
@@ -189,7 +186,7 @@ class PushshiftAPIBase(object):
         rate = self.num_suc/self.num_req*100
         remaining = self.req.limit
         if (self.num_batches % self.checkpoint == 0) and prefix == 'Checkpoint':
-            print(
+            log.info(
                 f'{prefix}:: Success Rate: {rate:.2f}% - Requests: {self.num_req} - Batches: {self.num_batches} - Items Remaining: {remaining}')
         elif prefix == 'Total':
             if remaining < 0:
@@ -210,6 +207,7 @@ class PushshiftAPIBase(object):
                 search_window=365,
                 dataset='reddit',
                 safe_exit=False,
+                cache_dir=None,
                 **kwargs):
 
         # raise error if aggs are requested
@@ -219,7 +217,7 @@ class PushshiftAPIBase(object):
 
         self.metadata_ = {}
         self.req = Request(copy.deepcopy(kwargs), kind,
-                           max_results_per_request, max_ids_per_request, mem_safe, safe_exit)
+                           max_results_per_request, max_ids_per_request, mem_safe, safe_exit, cache_dir=cache_dir)
 
         # reset stat tracking
         self._reset()
