@@ -16,7 +16,7 @@ log = logging.getLogger(__name__)
 class Request(object):
     """Request: Handles request information, response saving, and cache usage."""
 
-    def __init__(self, payload, kind, max_results_per_request, max_ids_per_request, mem_safe, safe_exit):
+    def __init__(self, payload, kind, max_results_per_request, max_ids_per_request, mem_safe, safe_exit, cache_dir=None):
         self.kind = kind
         self.max_ids_per_request = min(1000, max_ids_per_request)
         self.max_results_per_request = min(100, max_results_per_request)
@@ -35,14 +35,14 @@ class Request(object):
             # instantiate cache
             _tmp = copy.deepcopy(payload)
             _tmp['kind'] = kind
-            self._cache = Cache(_tmp, safe_exit)
+            self._cache = Cache(_tmp, safe_exit, cache_dir=cache_dir)
             if safe_exit:
                 info = self._cache.load_info()
                 if info:
                     self.req_list.extend(info['req_list'])
                     self.payload = info['payload']
                     self.limit = info['limit']
-                    print(
+                    log.info(
                         f'Loaded Cache:: Responses: {self._cache.size} - Pending Requests: {len(self.req_list)} - Items Remaining: {self.limit}')
         else:
             self._cache = None
@@ -54,7 +54,7 @@ class Request(object):
         try:
             getattr(signal, 'SIGHUP')
             sigs = ('TERM', 'HUP', 'INT')
-        except:
+        except Exception:
             sigs = ('TERM', 'INT')
 
         for sig in sigs:
@@ -63,7 +63,7 @@ class Request(object):
     def save_cache(self):
         # trim extra responses
         self.trim()
-        if self.safe_exit and self.limit and (self.limit == 0 or self.exit.is_set()):
+        if self.safe_exit and not self.limit == None and (self.limit == 0 or self.exit.is_set()):
             # save request info to cache
             self._cache.save_info(req_list=self.req_list,
                                   payload=self.payload, limit=self.limit)
@@ -129,7 +129,7 @@ class Request(object):
                 all_ids = self.payload['ids']
                 if len(all_ids) == 0 and (self.limit and self.limit > 0):
                     warnings.warn(
-                        f'{self.limit} items were not found in Pushshift')                
+                        f'{self.limit} items were not found in Pushshift')
                 self.limit = len(all_ids)
 
                 # remove ids from payload to prevent , -> %2C and increasing query length
@@ -190,3 +190,4 @@ class Request(object):
         if self.limit and self.limit < 0:
             log.debug(f'Trimming {self.limit*-1} requests')
             self.resp.responses = self.resp.responses[:self.limit]
+            self.limit = 0
